@@ -3,8 +3,8 @@
 
 __author__ = "Timo Stollenwerk (timo@zmag.de)"
 __license__ = "GNU General Public License (GPL)"
-__revision__ = "$Rev: 199 $"
-__date__ = "$Date: 2008-03-04 10:42:05 +0100 (Di, 04 Mrz 2008) $"
+__revision__ = "$Rev: 208 $"
+__date__ = "$Date: 2008-03-05 22:18:00 +0100 (Mi, 05 Mrz 2008) $"
 __URL__ = "$URL: https://svn.zmag.de/svn/python/docbook2sla/trunk/docbook2sla/docbook2sla.py $"
 
 import os, sys
@@ -17,6 +17,8 @@ from lxml import etree
 from zope.interface import implements
 from interfaces import IDocBook2Sla
 
+dirname = os.path.dirname(__file__)
+
 _debug = 1
 
 class NotValidXmlError(Exception): pass
@@ -29,6 +31,19 @@ class DocBook2Sla(object):
     def create(self, docbookfn, scribusfn, output_filename=None, validate=False):
         """ Creates a Scribus file from a DocBook source. """
 
+        # make stylesheets available
+        xsl_generateid = os.path.abspath(os.path.join(dirname, 'xsl', 'generate-id.xsl'))
+        if not os.path.exists(xsl_generateid):
+            raise IOError('%s does not exist' % xsl_generateid)
+
+        xsl_docbook2pageobject = os.path.abspath(os.path.join(dirname, 'xsl', 'docbook2pageobject.xsl'))
+        if not os.path.exists(xsl_docbook2pageobject):
+            raise IOError('%s does not exist' % xsl_docbook2pageobject)
+
+        xsl_wrapper = os.path.abspath(os.path.join(dirname, 'xsl', 'wrapper.xsl'))
+        if not os.path.exists(xsl_wrapper):
+            raise IOError('%s does not exist' % xsl_wrapper)
+
         if _debug:
             print"---- create ----"
 
@@ -37,22 +52,19 @@ class DocBook2Sla(object):
             print 'validate docbook: %s' % self.validate(docbookfn)
             print 'validate scribus: %s' % self.validate(scribusfn)
 
+
         # generate id : content.xml -> content.id.xml
-        docbook_with_ids = self.transform(docbookfn, 'xsl/generate-id.xsl')
+        docbook_with_ids = self.transform(docbookfn, xsl_generateid)
 
         #return open(docbook_with_ids, 'r').read()
 
         # docbook2pageobject : 01_content.id.xml -> pageobjects.xml
-        scribus_pageobjects = self.transform(docbook_with_ids,
-                                             'xsl/docbook2pageobject.xsl')
+        scribus_pageobjects = self.transform(docbook_with_ids, xsl_docbook2pageobject)
 
         #return open(scribus_pageobjects, 'r').read()
 
         # wrapper : pageobjects.xml + clean134.sla -> output.sla
-        output = self.transform(scribusfn,
-                                'xsl/wrapper.xsl',
-                                secondinputfn=scribus_pageobjects,
-                                )
+        output = self.transform(scribusfn, xsl_wrapper, secondinputfn=scribus_pageobjects)
 
         #return open(output, 'r').read()
 
@@ -65,6 +77,19 @@ class DocBook2Sla(object):
     def syncronize(self, docbookfn, scribusfn, output_filename=None, validate=False):
         """ Syncronize changes in a docbook file into a scribus file. """
 
+        # make stylesheets available
+        xsl_generateid = os.path.abspath(os.path.join(dirname, 'xsl', 'generate-id.xsl'))
+        if not os.path.exists(xsl_generateid):
+            raise IOError('%s does not exist' % xsl_generateid)
+
+        xsl_docbook2pageobject = os.path.abspath(os.path.join(dirname, 'xsl', 'docbook2pageobject.xsl'))
+        if not os.path.exists(xsl_docbook2pageobject):
+            raise IOError('%s does not exist' % xsl_docbook2pageobject)
+
+        xsl_wrapper = os.path.abspath(os.path.join(dirname, 'xsl', 'wrapper.xsl'))
+        if not os.path.exists(xsl_wrapper):
+            raise IOError('%s does not exist' % xsl_wrapper)
+
         if _debug:
             print"---- syncronize ----"
 
@@ -78,17 +103,13 @@ class DocBook2Sla(object):
                 raise
 
         # generate id : content.xml -> content.id.xml
-        docbook_with_ids = self.transform(docbookfn, 'xsl/generate-id.xsl')
+        docbook_with_ids = self.transform(docbookfn, xsl_generateid)
 
         # docbook2pageobject : 01_content.id.xml -> pageobjects.xml
-        scribus_pageobjects = self.transform(docbook_with_ids,
-                                             'xsl/docbook2pageobject.xsl')
+        scribus_pageobjects = self.transform(docbook_with_ids, xsl_docbook2pageobject)
 
         # wrapper : pageobjects.xml + clean134.sla -> output.sla
-        output = self.transform(scribusfn,
-                                'xsl/wrapper.xsl',
-                                secondinputfn=scribus_pageobjects,
-                                )
+        output = self.transform(scribusfn, xsl_wrapper, secondinputfn=scribus_pageobjects)
 
         # write to output filename if specified
         if output_filename:
@@ -148,6 +169,7 @@ class DocBook2Sla(object):
     def validate(self, fname):
         """ Validates XML against DocBook or Scribus XML Schema. """
 
+
         # split the filename into name and extension
         fe = os.path.splitext( fname )[1]
 
@@ -165,7 +187,13 @@ class DocBook2Sla(object):
                 raise NotValidXmlError, "%s is no valid %s file." % (fname, fe)
         elif fe == '.sla':
             # validate scribus
-            xmlschema_doc = etree.parse('schema/scribus.xsd')
+
+            # make scribus file available
+            xml_schema_scribus = os.path.abspath(os.path.join(dirname, 'schema', 'scribus.xsd'))
+            if not os.path.exists(xml_schema_scribus):
+                raise IOError('%s does not exist' % xml_schema_scribus)
+
+            xmlschema_doc = etree.parse(xml_schema_scribus)
             xmlschema = etree.XMLSchema(xmlschema_doc)
             if xmlschema.validate(xmltree):
                 return True
@@ -174,65 +202,6 @@ class DocBook2Sla(object):
         else:
             raise ValueError('Unsupported format: %s' % fe)
 
-    def generateId(self, docbookfn):
-        """ Generates IDs for every node of a DocBook file. """
-
-        # file -> elementtree
-        docbook = etree.parse(docbookfn)
-
-        # parse the xslt stylesheet
-        style = etree.parse('xsl/generate-id.xsl')
-
-        # load the xslt stylesheet
-        xslt = etree.XSLT(style)
-
-        # transform the xml file with the xslt stylesheet
-        result = xslt(docbook)
-
-        filename = newTempfile(suffix='.xml')
-        open(filename, 'wb').write(etree.tostring(result.getroot()))
-        return filename
-
-
-    def docbook2Pageobjects(self, docbookfn):
-        """ Converts DocBook nodes into Scribus pageobjects. """
-
-        # file -> elementtree
-        docbook = etree.parse(docbookfn)
-
-        # parse the xslt stylesheet
-        style = etree.parse('xsl/docbook2pageobject.xsl')
-
-        # load the xslt stylesheet
-        xslt = etree.XSLT(style)
-
-        # transform the xml file with the xslt stylesheet
-        result = xslt(docbook, uselayout="'tests/data/scribus/clean134.sla'")
-
-        filename = newTempfile(suffix='.xml')
-        open(filename, 'wb').write(etree.tostring(result.getroot()))
-        return filename
-
-
-    def wrapper(self, contentfn, scribusfn):
-        """ Wraps up Scibus pageobjects with a Scribus document. """
-
-        # parse the scribus wrapper
-        scribuswrapper = etree.parse(scribusfn)
-
-        # parse the xslt stylesheet
-        style = etree.parse('xsl/wrapper.xsl')
-
-        # load the xslt stylesheet
-        xslt = etree.XSLT(style)
-
-        # transform the xml file with the xslt stylesheet
-        result = xslt(scribuswrapper, content="'../content.sla'")
-
-        filename = newTempfile(suffix='.sla')
-        open(filename, 'wb').write(etree.tostring(result.getroot()))
-        return filename
-
     def write(self, tmpfn, outputfn):
         """ Write tempfile into output file. """
         tmpFile = open(tmpfn,"r")
